markuptools.get_up_markup_attached_to_component
===============================================

.. autofunction:: abjad.tools.markuptools.get_up_markup_attached_to_component.get_up_markup_attached_to_component
